from zafiaonline.api_client.api_decorators import ApiDecorators
from zafiaonline.api_client.global_chat_methods import GlobalChat
from zafiaonline.api_client.player_methods import Players
from zafiaonline.api_client.room_methods import Room, MatchMaking
from zafiaonline.api_client.user_methods import Auth, User
from zafiaonline.api_client.https_api import HttpsApi
from zafiaonline.api_client.zafia_api import ZafiaApi

__all__: tuple[str, ...] = (
    #Decorators
    "ApiDecorators",

    #Chat
    "GlobalChat",

    #Players
    "Players",
    "Auth",
    "User",

    #Room
    "Room",
    "MatchMaking",

    #Other
    "HttpsApi",
    "ZafiaApi",
)
